@@ -5,11 +5,9 @@
 
 package kotlin
 
-import kotlin.internal.ActualizeByJvmBuiltinProvider
 
 /**
  * Nothing has no instances. You can use Nothing to represent "a value that never exists": for example,
  * if a function has the return type of Nothing, it means that it never returns (always throws an exception).
  */
-@ActualizeByJvmBuiltinProvider
 public expect class Nothing // no constructor
